@@ -25,7 +25,7 @@
 
   This software is a computer program whose purpose is to provide an
   environment for safe floating-point code development. It is
-  particularily targeted to the automatized implementation of
+  particularly targeted to the automated implementation of
   mathematical floating-point libraries (libm). Amongst other features,
   it offers a certified infinity norm, an automatic polynomial
   implementer and a fast Remez algorithm.
@@ -496,6 +496,9 @@ libraryHandle *getLibraryHandle(char *libraryName, int type) {
     otherLibraries[0] = openedConstantLibraries;
     otherLibraries[1] = openedFunctionLibraries;
     break;
+  default:
+    sollyaFprintf(stderr,"Error: getLibraryHandle: unknown type (%d)\n", type);
+    exit(1);
   }
   otherDlfcnHandle = NULL;
   for (i=0,foundElsewhere=0;(i<2)&&(!foundElsewhere);i++) {
@@ -753,7 +756,7 @@ void freeFunctionLibraries() {
       if (dlerror() == NULL) {
 	res = myFunction();
 	if (res) {
-	  printMessage(1,SOLLYA_MSG_LIBRARY_CLOSER_ERROR,"Warning: while closing libary \"%s\", the function \"sollya_external_lib_close\" was found and called but it signaled the error %d\n",currLibHandle->libraryName,res);
+	  printMessage(1,SOLLYA_MSG_LIBRARY_CLOSER_ERROR,"Warning: while closing library \"%s\", the function \"sollya_external_lib_close\" was found and called but it signaled the error %d\n",currLibHandle->libraryName,res);
 	}
       }
     }
@@ -776,7 +779,7 @@ void freeFunctionLibraries() {
     if (!(currLibHandle->shallowCopy)) {
       dlerror();
       if (dlclose(currLibHandle->libraryDescriptor) != 0)
-	printMessage(1,SOLLYA_MSG_COULD_NOT_CLOSE_LIBRARY,"Warning: could not close libary \"%s\": %s\n",currLibHandle->libraryName,dlerror());
+	printMessage(1,SOLLYA_MSG_COULD_NOT_CLOSE_LIBRARY,"Warning: could not close library \"%s\": %s\n",currLibHandle->libraryName,dlerror());
     }
     safeFree(currLibHandle->libraryName);
     safeFree(currLibHandle);
@@ -986,7 +989,7 @@ void freeConstantLibraries() {
       if (dlerror() == NULL) {
 	res = myFunction();
 	if (res) {
-	  printMessage(1,SOLLYA_MSG_LIBRARY_CLOSER_ERROR,"Warning: while closing libary \"%s\", the function \"sollya_external_lib_close\" was found and called but it signaled the error %d\n",currLibHandle->libraryName,res);
+	  printMessage(1,SOLLYA_MSG_LIBRARY_CLOSER_ERROR,"Warning: while closing library \"%s\", the function \"sollya_external_lib_close\" was found and called but it signaled the error %d\n",currLibHandle->libraryName,res);
 	}
       }
     }
@@ -1009,7 +1012,7 @@ void freeConstantLibraries() {
     if (!(currLibHandle->shallowCopy)) {
       dlerror();
       if (dlclose(currLibHandle->libraryDescriptor) != 0)
-	printMessage(1,SOLLYA_MSG_COULD_NOT_CLOSE_LIBRARY,"Warning: could not close libary \"%s\": %s\n",currLibHandle->libraryName,dlerror());
+	printMessage(1,SOLLYA_MSG_COULD_NOT_CLOSE_LIBRARY,"Warning: could not close library \"%s\": %s\n",currLibHandle->libraryName,dlerror());
     }
     safeFree(currLibHandle->libraryName);
     safeFree(currLibHandle);
@@ -1244,7 +1247,7 @@ void freeProcLibraries() {
       if (dlerror() == NULL) {
 	res = myFunction();
 	if (res) {
-	  printMessage(1,SOLLYA_MSG_LIBRARY_CLOSER_ERROR,"Warning: while closing libary \"%s\", the function \"sollya_external_lib_close\" was found and called but it signaled the error %d\n",currLibHandle->libraryName,res);
+	  printMessage(1,SOLLYA_MSG_LIBRARY_CLOSER_ERROR,"Warning: while closing library \"%s\", the function \"sollya_external_lib_close\" was found and called but it signaled the error %d\n",currLibHandle->libraryName,res);
 	}
       }
     }
@@ -1268,7 +1271,7 @@ void freeProcLibraries() {
     if (!(currLibHandle->shallowCopy)) {
       dlerror();
       if (dlclose(currLibHandle->libraryDescriptor) != 0)
-	printMessage(1,SOLLYA_MSG_COULD_NOT_CLOSE_LIBRARY,"Warning: could not close libary \"%s\": %s\n",currLibHandle->libraryName,dlerror());
+	printMessage(1,SOLLYA_MSG_COULD_NOT_CLOSE_LIBRARY,"Warning: could not close library \"%s\": %s\n",currLibHandle->libraryName,dlerror());
     }
     safeFree(currLibHandle->libraryName);
     safeFree(currLibHandle);
