@@ -28,7 +28,7 @@
 
   This software is a computer program whose purpose is to provide an
   environment for safe floating-point code development. It is
-  particularily targeted to the automatized implementation of
+  particularly targeted to the automated implementation of
   mathematical floating-point libraries (libm). Amongst other features,
   it offers a certified infinity norm, an automatic polynomial
   implementer and a fast Remez algorithm.
@@ -498,20 +498,20 @@ void findZero(mpfr_t res, node *f, node *f_diff, mpfr_t a, mpfr_t b, int sgnfa,
     }
     /* The cases (-sngfa, * *) and (* * sgnfa) can be separated into subcases : */
     if ((sgnfepsa==codeNegfa) && (sgnf0==3) && (sgnfepsb==codefa)) {
-      printMessage(3, SOLLYA_MSG_NEWTON_FUNC_APPEARS_TO_HAVE_MORE_THAN_ONE_ZERO, "Warning (Newton's algorithm): the function has more than one zero in the interval.\n");
-      printMessage(3, SOLLYA_MSG_CONTINUATION, "Warning (Newton's algorithm): 0 seems to be one of them but wa cannot prove it.\n");
+      printMessage(4, SOLLYA_MSG_NEWTON_FUNC_APPEARS_TO_HAVE_MORE_THAN_ONE_ZERO, "Warning (Newton's algorithm): the function has more than one zero in the interval.\n");
+      printMessage(4, SOLLYA_MSG_CONTINUATION, "Warning (Newton's algorithm): 0 seems to be one of them but wa cannot prove it.\n");
       mpfr_set(res, zero_mpfr, GMP_RNDN);
       stop_algo = 1;
     }
     if ((sgnfepsa==codeNegfa) && (sgnf0==codefa) && (sgnfepsb==codefa)) {
-      printMessage(3, SOLLYA_MSG_NEWTON_FUNC_APPEARS_TO_HAVE_MORE_THAN_ONE_ZERO, "Warning (Newton's algorithm): the function has more than one zero in the interval.\n");
-      printMessage(3, SOLLYA_MSG_CONTINUATION, "Warning (Newton's algorithm): one of them is too close to zero for being accurately determined.\n");
+      printMessage(4, SOLLYA_MSG_NEWTON_FUNC_APPEARS_TO_HAVE_MORE_THAN_ONE_ZERO, "Warning (Newton's algorithm): the function has more than one zero in the interval.\n");
+      printMessage(4, SOLLYA_MSG_CONTINUATION, "Warning (Newton's algorithm): one of them is too close to zero for being accurately determined.\n");
       mpfr_set(res, epsa, GMP_RNDU);
       stop_algo = 1;
     }
     if ((sgnfepsa==codeNegfa) && (sgnf0==codeNegfa) && (sgnfepsb==codefa)) {
-      printMessage(3, SOLLYA_MSG_NEWTON_FUNC_APPEARS_TO_HAVE_MORE_THAN_ONE_ZERO, "Warning (Newton's algorithm): the function has more than one zero in the interval.\n");
-      printMessage(3, SOLLYA_MSG_CONTINUATION, "Warning (Newton's algorithm): one of them is too close to zero for being accurately determined.\n");
+      printMessage(4, SOLLYA_MSG_NEWTON_FUNC_APPEARS_TO_HAVE_MORE_THAN_ONE_ZERO, "Warning (Newton's algorithm): the function has more than one zero in the interval.\n");
+      printMessage(4, SOLLYA_MSG_CONTINUATION, "Warning (Newton's algorithm): one of them is too close to zero for being accurately determined.\n");
       mpfr_set(res, epsb, GMP_RNDD);
       stop_algo = 1;
     }
@@ -965,11 +965,11 @@ void single_step_remez(mpfr_t newx, mpfr_t err_newx, mpfr_t *x,
 
   /* Introduce newx */
   if(mpfr_sgn(err_newx)*mpfr_sgn(epsilon)==1) {
-    printMessage(3,SOLLYA_MSG_REMEZ_EXCHANGE_TAKE_A_CERTAIN_MINIMUM,"Remez: exchange algorithm takes the minimum (%.16v) at place %d\n",mini,argmini);
+    printMessage(4,SOLLYA_MSG_REMEZ_EXCHANGE_TAKE_A_CERTAIN_MINIMUM,"Remez: exchange algorithm takes the minimum (%.16v) at place %d\n",mini,argmini);
     mpfr_set(x[argmini], newx, GMP_RNDN);
   }
   else {
-    printMessage(3,SOLLYA_MSG_REMEZ_EXCHANGE_TAKE_A_CERTAIN_MAXIMUM,"Remez: exchange algorithm takes the maximum (%.16v) at place %d\n",maxi,argmaxi);
+    printMessage(4,SOLLYA_MSG_REMEZ_EXCHANGE_TAKE_A_CERTAIN_MAXIMUM,"Remez: exchange algorithm takes the maximum (%.16v) at place %d\n",maxi,argmaxi);
     mpfr_set(x[argmaxi], newx, GMP_RNDN);
   }
 
@@ -1011,6 +1011,9 @@ void quickFindZeros(mpfr_t *res, mpfr_t *curr_points,
 		    mpfr_t a, mpfr_t b, mp_prec_t prec) {
   long int n = 50*(deg+2);
   long int i=0;
+  int tooManyOscillations = 0; /* This variable is used to ensure that the
+                                  message "the function oscillates too much"
+                                  is displayed only once */
 
   /* The variable test is used to check that the maximum (in absolute value)
      of the error will be inserted in the new list of points.
@@ -1050,18 +1053,22 @@ void quickFindZeros(mpfr_t *res, mpfr_t *curr_points,
   mpfr_add(x2,a,h,GMP_RNDN);
 
   evaluateFaithfulWithCutOffFast(y1, tree, diff_tree, x1, zero_mpfr, prec);
-  evaluateFaithfulWithCutOffFast(y2, tree, diff_tree, x2, zero_mpfr, prec);
   evaluateFaithfulWithCutOffFast(alpha1, diff_tree, NULL, x1, zero_mpfr, prec);
-  evaluateFaithfulWithCutOffFast(alpha2, diff_tree, NULL, x2, zero_mpfr, prec);
 
   while(mpfr_lessequal_p(x2,b)) {
+    evaluateFaithfulWithCutOffFast(y2, tree, diff_tree, x2, zero_mpfr, prec);
+    evaluateFaithfulWithCutOffFast(alpha2, diff_tree, NULL, x2, zero_mpfr, prec);
     if( (mpfr_sgn(y1)==0) || (mpfr_sgn(y2)==0) || (mpfr_sgn(y1) != mpfr_sgn(y2))) {
       if (mpfr_sgn(y1)==0) {
 	evaluateFaithfulWithCutOffFast(z, error, tree, x1, zero_mpfr, prec);
 	if (mpfr_sgn(z)*mpfr_sgn(alpha1)<0) {
 	  i++;
-	  if(i>deg+2)
-	    printMessage(1,SOLLYA_MSG_REMEZ_FUNCTION_OSCILLATES_TOO_MUCH,"Warning: the function oscillates too much. Nevertheless, we try to continue.\n");
+	  if(i>deg+2) {
+	    if (!tooManyOscillations)
+              printMessage(1,SOLLYA_MSG_REMEZ_FUNCTION_OSCILLATES_TOO_MUCH,
+                           "Warning: the function oscillates too much. Nevertheless, we try to continue.\n");
+            tooManyOscillations = 1;
+          }
 	  else mpfr_set(res[i-1], x1, GMP_RNDN);
 	}
 	if (mpfr_cmpabs(z,maxi)>0) {
@@ -1096,8 +1103,12 @@ void quickFindZeros(mpfr_t *res, mpfr_t *curr_points,
 	  evaluateFaithfulWithCutOffFast(z, error, tree, x2, zero_mpfr, prec);
 	  if (mpfr_sgn(z)*mpfr_sgn(alpha2)<0) {
 	    i++;
-	    if(i>deg+2)
-	      printMessage(1,SOLLYA_MSG_REMEZ_FUNCTION_OSCILLATES_TOO_MUCH,"Warning: the function oscillates too much. Nevertheless, we try to continue.\n");
+	    if(i>deg+2) {
+              if (!tooManyOscillations)
+                printMessage(1,SOLLYA_MSG_REMEZ_FUNCTION_OSCILLATES_TOO_MUCH,
+                             "Warning: the function oscillates too much. Nevertheless, we try to continue.\n");
+              tooManyOscillations = 1;
+            }
 	    else mpfr_set(res[i-1], x2, GMP_RNDN);
 	  }
 	  if (mpfr_cmpabs(z,maxi)>0) {
@@ -1113,8 +1124,12 @@ void quickFindZeros(mpfr_t *res, mpfr_t *curr_points,
 	  evaluateFaithfulWithCutOffFast(alpha, diff_tree, NULL, x , zero_mpfr, prec);
 	  if (mpfr_sgn(z)*mpfr_sgn(alpha)<0) {
 	    i++;
-	    if(i>deg+2)
-	      printMessage(1,SOLLYA_MSG_REMEZ_FUNCTION_OSCILLATES_TOO_MUCH,"Warning: the function oscillates too much. Nevertheless, we try to continue.\n");
+	    if(i>deg+2) {
+              if (!tooManyOscillations)
+                printMessage(1,SOLLYA_MSG_REMEZ_FUNCTION_OSCILLATES_TOO_MUCH,
+                             "Warning: the function oscillates too much. Nevertheless, we try to continue.\n");
+              tooManyOscillations = 1;
+            }
 	    else mpfr_set(res[i-1], x, GMP_RNDN);
 	  }
 	  if (mpfr_cmpabs(z,maxi)>0) {
@@ -1130,8 +1145,6 @@ void quickFindZeros(mpfr_t *res, mpfr_t *curr_points,
     mpfr_set(x1,x2,GMP_RNDN);
     mpfr_add(x2,x2,h,GMP_RNDN);
     mpfr_set(y1,y2,GMP_RNDN);
-    evaluateFaithfulWithCutOffFast(y2, tree, diff_tree, x2, zero_mpfr, prec);
-    evaluateFaithfulWithCutOffFast(alpha2, diff_tree, NULL, x2, zero_mpfr, prec);
   }
 
   if ((i<deg)||(i>deg+2)||(!HaarCompliant)||(!test)) {
@@ -1484,9 +1497,9 @@ int qualityOfError(mpfr_t computedQuality, mpfr_t infinityNorm, mpfr_t *x,
     }
   }
 
-  printMessage(3,SOLLYA_MSG_REMEZ_THE_NEW_POINTS_ARE_CERTAIN_VALUES,"The new points are: ");
-  for(i=1; i<=n; i++) printMessage(3,SOLLYA_MSG_CONTINUATION,"%v ",z[i-1]);
-  printMessage(3,SOLLYA_MSG_CONTINUATION,"\n");
+  printMessage(4,SOLLYA_MSG_REMEZ_THE_NEW_POINTS_ARE_CERTAIN_VALUES,"The new points are: ");
+  for(i=1; i<=n; i++) printMessage(4,SOLLYA_MSG_CONTINUATION,"%v ",z[i-1]);
+  printMessage(4,SOLLYA_MSG_CONTINUATION,"\n");
 
   /* Test the quality of the current error */
 
@@ -1509,7 +1522,7 @@ int qualityOfError(mpfr_t computedQuality, mpfr_t infinityNorm, mpfr_t *x,
   if(computedQuality!=NULL) mpfr_set(computedQuality, var_mpfr, GMP_RNDU);
   if(infinityNorm!=NULL) mpfr_set(infinityNorm, max_val, GMP_RNDU);
 
-  printMessage(3, SOLLYA_MSG_REMEZ_THE_CURRENT_NORM_TAKES_A_CERTAIN_VALUE, "Current norm: %v (1 +/- %.3v)\n",max_val,var_mpfr);
+  printMessage(2, SOLLYA_MSG_REMEZ_THE_CURRENT_NORM_TAKES_A_CERTAIN_VALUE, "Current norm: %v (1 +/- %.3v)\n",max_val,var_mpfr);
 
   free_memory(error);
   free_memory(error_diff);
@@ -1545,7 +1558,7 @@ int qualityOfError(mpfr_t computedQuality, mpfr_t infinityNorm, mpfr_t *x,
 */
 node *remezAux(node *f, node *w, chain *monomials, mpfr_t u, mpfr_t v, mp_prec_t prec, mpfr_t quality, mpfr_t satisfying_error, mpfr_t target_error) {
   int freeDegrees = lengthChain(monomials);
-  int i, j, r, count, test, crash, HaarCompliant;
+  int i, j, r, count, test, crash, HaarCompliant, forEverNotHaarCompliant;
   mpfr_t zero_mpfr, var1, var2, var3, computedQuality, infinityNorm;
   node *temp_tree;
   node *temp_tree2;
@@ -1562,6 +1575,7 @@ node *remezAux(node *f, node *w, chain *monomials, mpfr_t u, mpfr_t v, mp_prec_t
   mpfr_t *ai_vect;
   mpfr_t *lambdai_vect;
   mpfr_t *previous_lambdai_vect;
+  mpfr_t previous_epsilon;
   mpfr_t perturb;
   gmp_randstate_t random_state;
   int quality_prec;
@@ -1570,6 +1584,8 @@ node *remezAux(node *f, node *w, chain *monomials, mpfr_t u, mpfr_t v, mp_prec_t
   res = NULL;
   /* End of compiler happiness */
 
+  forEverNotHaarCompliant = 0;
+
   quality_prec = (mpfr_regular_p(quality)?(10 - mpfr_get_exp(quality)):prec);
 
   gmp_randinit_default(random_state);
@@ -1587,6 +1603,9 @@ node *remezAux(node *f, node *w, chain *monomials, mpfr_t u, mpfr_t v, mp_prec_t
   mpfr_init2(zero_mpfr, 53);
   mpfr_set_d(zero_mpfr, 0., GMP_RNDN);
 
+  mpfr_init2(previous_epsilon, prec);
+  mpfr_set(previous_epsilon, zero_mpfr, GMP_RNDN);
+
   if (mpfr_get_prec(quality)>prec) mpfr_init2(computedQuality, mpfr_get_prec(quality));
   else mpfr_init2(computedQuality, prec);
 
@@ -1753,7 +1772,7 @@ node *remezAux(node *f, node *w, chain *monomials, mpfr_t u, mpfr_t v, mp_prec_t
          N lets us determine the modified alternation property
          M lets us solve the interpolation problem
       */
-      printMessage(3, SOLLYA_MSG_REMEZ_COMPUTING_THE_MATRIX, "Step %d\nComputing the matrix...\n",count);
+      printMessage(4, SOLLYA_MSG_REMEZ_COMPUTING_THE_MATRIX, "Step %d\nComputing the matrix...\n",count);
       pushTimeCounter();
 
       for (i=1 ; i <= freeDegrees+1 ; i++) {
@@ -1804,6 +1823,7 @@ node *remezAux(node *f, node *w, chain *monomials, mpfr_t u, mpfr_t v, mp_prec_t
 	}
 	if(count==0) HaarCompliant=1;
       }
+      if (forEverNotHaarCompliant) HaarCompliant = 0;
 
       for (i=1 ; i <= freeDegrees+1 ; i++) {
 	if (mpfr_sgn(lambdai_vect[i-1])>0)
@@ -1846,8 +1866,8 @@ node *remezAux(node *f, node *w, chain *monomials, mpfr_t u, mpfr_t v, mp_prec_t
 
       poly = constructPolynomialFromArray(ai_vect, monomials_tree, freeDegrees);
 
-      printMessage(4, SOLLYA_MSG_REMEZ_THE_COMPUTED_POLY_HAS_A_CERTAIN_VALUE, "The computed polynomial is %b\n",poly);
-      printMessage(3, SOLLYA_MSG_REMEZ_CURRENT_EPSILON_HAS_A_CERTAIN_VALUE, "Current value of epsilon : %.16v\n",ai_vect[freeDegrees]);
+      printMessage(3, SOLLYA_MSG_REMEZ_THE_COMPUTED_POLY_HAS_A_CERTAIN_VALUE, "The computed polynomial is %b\n",poly);
+      printMessage(2, SOLLYA_MSG_REMEZ_CURRENT_EPSILON_HAS_A_CERTAIN_VALUE, "Current value of epsilon : %.16v\n",ai_vect[freeDegrees]);
 
       /* Plotting the error curve */
       /*     node *plotTemp; */
@@ -1886,7 +1906,7 @@ node *remezAux(node *f, node *w, chain *monomials, mpfr_t u, mpfr_t v, mp_prec_t
 	   correctly cases when the error oscillates too much
 	*/
 	temp_tree = addMemRef(makeSub(makeMul(copyTree(poly), copyTree(w)), copyTree(f)));
-	uncertifiedInfnorm(infinityNorm, temp_tree, u, v, getToolPoints(), quality_prec);
+	uncertifiedInfnorm(infinityNorm, NULL, temp_tree, u, v, getToolPoints(), quality_prec);
 
 	printMessage(1,SOLLYA_MSG_REMEZ_THE_BEST_POLY_GIVES_A_CERTAIN_ERROR,"The best polynomial obtained gives an error of %v\n",infinityNorm);
 
@@ -1903,7 +1923,8 @@ node *remezAux(node *f, node *w, chain *monomials, mpfr_t u, mpfr_t v, mp_prec_t
 	safeFree(x);
 
 	mpfr_clear(zero_mpfr);
-	mpfr_clear(var1);
+        mpfr_clear(previous_epsilon);
+        mpfr_clear(var1);
 	mpfr_clear(var2);
 	mpfr_clear(var3);
 	mpfr_clear(computedQuality);
@@ -1952,6 +1973,11 @@ node *remezAux(node *f, node *w, chain *monomials, mpfr_t u, mpfr_t v, mp_prec_t
 	mpfr_set(previous_lambdai_vect[i-1], lambdai_vect[i-1], GMP_RNDN);
       }
 
+      if (mpfr_cmpabs(previous_epsilon, ai_vect[freeDegrees]) > 0) {
+        forEverNotHaarCompliant = 1;
+        printMessage(2, SOLLYA_MSG_REMEZ_SWITCHING_DEFINITIVELY_TO_SLOW_ALGORITHM, "Remez: multipoint algorithm failed due to lack of Haar condition. Switching back to single point algorithm.\n");
+      }
+      mpfr_set(previous_epsilon, ai_vect[freeDegrees], GMP_RNDN);
     }
 
     res = NULL;
@@ -1973,7 +1999,8 @@ node *remezAux(node *f, node *w, chain *monomials, mpfr_t u, mpfr_t v, mp_prec_t
       temp_tree_simplified = simplifyTreeErrorfree(temp_tree);
       free_memory(temp_tree);
       temp_tree = temp_tree_simplified;
-      uncertifiedInfnorm(infinityNorm, temp_tree, u, v, getToolPoints(), quality_prec);
+      uncertifiedInfnorm(infinityNorm, &var1, temp_tree, u, v, getToolPoints(), quality_prec); /* var1 now contains a point where the max is reached */
+      evaluateFaithfulWithCutOffFast(var2, temp_tree, NULL, var1, zero_mpfr, prec); /* var2 is the value of the error at a point where the norm is reached */
       free_memory(temp_tree);
       /* end of the temporary check */
 
@@ -2000,6 +2027,8 @@ node *remezAux(node *f, node *w, chain *monomials, mpfr_t u, mpfr_t v, mp_prec_t
     if(res==NULL) {
       printMessage(2, SOLLYA_MSG_REMEZ_FAILS_AND_LOOPS_AGAIN, "Warning: Remez algorithm failed (too many oscillations?)\nLooping again\n");
       HaarCompliant=2;
+      /* Attempt to (somehow) fix bug #8867: in case we forgot a point during the algorithm, we force its introduction now */
+      single_step_remez(var1, var2, x, monomials_tree, w, lambdai_vect, ai_vect[freeDegrees], freeDegrees+1, prec);
     }
   }
 
@@ -2016,6 +2045,7 @@ node *remezAux(node *f, node *w, chain *monomials, mpfr_t u, mpfr_t v, mp_prec_t
 
 
   mpfr_clear(zero_mpfr);
+  mpfr_clear(previous_epsilon);
   mpfr_clear(var1);
   mpfr_clear(var2);
   mpfr_clear(var3);
@@ -2310,7 +2340,7 @@ void firstStepContinuousMinimaxChebychevsPoints(mpfr_t *h, node *func, node *wei
   poly = addMemRef(elementaryStepRemezAlgorithm(NULL, func, weight, x, monomials_tree, n, currentPrec));
 
   error = addMemRef(makeSub(makeMul(copyTree(poly), copyTree(weight)), copyTree(func)));
-  uncertifiedInfnorm(tmp, error, a, b, 3*n, 20);
+  uncertifiedInfnorm(tmp, NULL, error, a, b, 3*n, 20);
   mpfr_set(*h, tmp, GMP_RNDU);
 
   mpfr_clear(tmp);
@@ -2359,7 +2389,7 @@ rangetype guessDegree(node *func, node *weight, mpfr_t a, mpfr_t b, mpfr_t eps,
     sollya_mpfi_interv_fr(tmp1, a, b);
     evaluateInterval(tmp2, weight, NULL, tmp1);
     if (sollya_mpfi_has_infinity(tmp2)) {
-      printMessage(1, SOLLYA_MSG_GUESSDEGREE_POSSIBLE_SINGULAR_WEIGHT, "Warning: guessdegree: the weight function might not be continuous over the given interval.\nThis is not allowed but it is the user's responsability to check it.\nNo other test will be performed, but be aware that the command is allowed to return anything in this case.\n");
+      printMessage(1, SOLLYA_MSG_GUESSDEGREE_POSSIBLE_SINGULAR_WEIGHT, "Warning: guessdegree: the weight function might not be continuous over the given interval.\nThis is not allowed but it is the user's responsibility to check it.\nNo other test will be performed, but be aware that the command is allowed to return anything in this case.\n");
     }
     sollya_mpfi_clear(tmp1);
     sollya_mpfi_clear(tmp2);
