@@ -31,7 +31,7 @@
 
   This software is a computer program whose purpose is to provide an
   environment for safe floating-point code development. It is
-  particularily targeted to the automatized implementation of
+  particularly targeted to the automated implementation of
   mathematical floating-point libraries (libm). Amongst other features,
   it offers a certified infinity norm, an automatic polynomial
   implementer and a fast Remez algorithm.
@@ -268,13 +268,6 @@ extern "C" {
 							    void (*)(void *(**)(size_t),
 								     void *(**)(void *, size_t, size_t),
 								     void (**)(void *, size_t)));
-  int sollya_lib_init_with_arguments_with_custom_memory_function_modifiers(int, char **,
-									   void (*)(void *(*)(size_t),
-										    void *(*)(void *, size_t, size_t),
-										    void (*)(void *, size_t)),
-									   void (*)(void *(**)(size_t),
-										    void *(**)(void *, size_t, size_t),
-										    void (**)(void *, size_t)));
   int sollya_lib_init_with_custom_memory_functions_with_custom_memory_function_modifiers(void *(*)(size_t),
 											 void *(*)(size_t, size_t),
 											 void *(*)(void *, size_t),
